@@ -36,11 +36,11 @@ Backup::EZ - Simple backups based on rsync
 
 =head1 VERSION
 
-Version 0.32
+Version 0.33
 
 =cut
 
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 
 =head1 SYNOPSIS
 
@@ -340,11 +340,11 @@ sub _rsync2 {
     }
 
     if ($link_dest) {
-        push @$extra_opts, "--link-dest $link_dest";
+        push @$extra_opts, sprintf '--link-dest "%s"', $link_dest;
     }
 
     if ( $self->{exclude_file} ) {
-        push @$extra_opts, "--exclude-from " . $self->{exclude_file};
+        push @$extra_opts, sprintf '--exclude-from "%s"', $self->{exclude_file};
     }
 
     $self->_mk_dest_dir( sprintf( "%s%s", $self->_get_dest_tmp_dir, $dir ) );
